@@ -15,7 +15,9 @@ import sys
 from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
+    BuildTypeType,
     ComponentTypeType,
+    DiskImageFormatType,
     EbsVolumeTypeType,
     ImageStatusType,
     ImageTypeType,
@@ -118,6 +120,8 @@ __all__ = (
     "ImageVersionTypeDef",
     "ImportComponentRequestRequestTypeDef",
     "ImportComponentResponseTypeDef",
+    "ImportVmImageRequestRequestTypeDef",
+    "ImportVmImageResponseTypeDef",
     "InfrastructureConfigurationSummaryTypeDef",
     "InfrastructureConfigurationTypeDef",
     "InstanceBlockDeviceMappingTypeDef",
@@ -160,6 +164,7 @@ __all__ = (
     "PutImageRecipePolicyRequestRequestTypeDef",
     "PutImageRecipePolicyResponseTypeDef",
     "ResponseMetadataTypeDef",
+    "S3ExportConfigurationTypeDef",
     "S3LogsTypeDef",
     "ScheduleTypeDef",
     "StartImagePipelineExecutionRequestRequestTypeDef",
@@ -868,6 +873,7 @@ _OptionalDistributionTypeDef = TypedDict(
         "containerDistributionConfiguration": "ContainerDistributionConfigurationTypeDef",
         "licenseConfigurationArns": Sequence[str],
         "launchTemplateConfigurations": Sequence["LaunchTemplateConfigurationTypeDef"],
+        "s3ExportConfiguration": "S3ExportConfigurationTypeDef",
     },
     total=False,
 )
@@ -1168,6 +1174,7 @@ ImageSummaryTypeDef = TypedDict(
         "dateCreated": str,
         "outputResources": "OutputResourcesTypeDef",
         "tags": Dict[str, str],
+        "buildType": BuildTypeType,
     },
     total=False,
 )
@@ -1202,6 +1209,7 @@ ImageTypeDef = TypedDict(
         "dateCreated": str,
         "outputResources": "OutputResourcesTypeDef",
         "tags": Dict[str, str],
+        "buildType": BuildTypeType,
     },
     total=False,
 )
@@ -1217,6 +1225,7 @@ ImageVersionTypeDef = TypedDict(
         "osVersion": str,
         "owner": str,
         "dateCreated": str,
+        "buildType": BuildTypeType,
     },
     total=False,
 )
@@ -1262,6 +1271,43 @@ ImportComponentResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredImportVmImageRequestRequestTypeDef = TypedDict(
+    "_RequiredImportVmImageRequestRequestTypeDef",
+    {
+        "name": str,
+        "semanticVersion": str,
+        "platform": PlatformType,
+        "vmImportTaskId": str,
+        "clientToken": str,
+    },
+)
+_OptionalImportVmImageRequestRequestTypeDef = TypedDict(
+    "_OptionalImportVmImageRequestRequestTypeDef",
+    {
+        "description": str,
+        "osVersion": str,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class ImportVmImageRequestRequestTypeDef(
+    _RequiredImportVmImageRequestRequestTypeDef, _OptionalImportVmImageRequestRequestTypeDef
+):
+    pass
+
+
+ImportVmImageResponseTypeDef = TypedDict(
+    "ImportVmImageResponseTypeDef",
+    {
+        "requestId": str,
+        "imageArn": str,
+        "clientToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 InfrastructureConfigurationSummaryTypeDef = TypedDict(
     "InfrastructureConfigurationSummaryTypeDef",
     {
@@ -1754,6 +1800,29 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+_RequiredS3ExportConfigurationTypeDef = TypedDict(
+    "_RequiredS3ExportConfigurationTypeDef",
+    {
+        "roleName": str,
+        "diskImageFormat": DiskImageFormatType,
+        "s3Bucket": str,
+    },
+)
+_OptionalS3ExportConfigurationTypeDef = TypedDict(
+    "_OptionalS3ExportConfigurationTypeDef",
+    {
+        "s3Prefix": str,
+    },
+    total=False,
+)
+
+
+class S3ExportConfigurationTypeDef(
+    _RequiredS3ExportConfigurationTypeDef, _OptionalS3ExportConfigurationTypeDef
+):
+    pass
+
+
 S3LogsTypeDef = TypedDict(
     "S3LogsTypeDef",
     {
